@@ -6,6 +6,8 @@ import (
 	"strings"
 	"time"
 
+	"sigs.k8s.io/yaml"
+
 	"github.com/gophercloud/gophercloud"
 	"github.com/gophercloud/gophercloud/openstack/baremetal/noauth"
 	"github.com/gophercloud/gophercloud/openstack/baremetal/v1/nodes"
@@ -455,15 +457,24 @@ func (p *ironicProvisioner) InspectHardware() (result provisioner.Result, detail
 	status, err := introspection.GetIntrospectionStatus(p.inspector, ironicNode.UUID).Extract()
 	if err != nil {
 		if _, isNotFound := err.(gophercloud.ErrDefault404); isNotFound {
-			p.log.Info("starting new hardware inspection")
-			result, err = p.changeNodeProvisionState(
-				ironicNode,
-				nodes.ProvisionStateOpts{Target: nodes.TargetInspect},
-			)
-			if err == nil {
-				p.publisher("InspectionStarted", "Hardware inspection started")
+			switch nodes.ProvisionState(ironicNode.ProvisionState) {
+			case nodes.Inspecting, nodes.InspectWait:
+				p.log.Info("inspection already started")
+				result.Dirty = true
+				result.RequeueAfter = introspectionRequeueDelay
+				err = nil
+				return
+			default:
+				p.log.Info("starting new hardware inspection")
+				result, err = p.changeNodeProvisionState(
+					ironicNode,
+					nodes.ProvisionStateOpts{Target: nodes.TargetInspect},
+				)
+				if err == nil {
+					p.publisher("InspectionStarted", "Hardware inspection started")
+				}
+				return
 			}
-			return
 		}
 		err = errors.Wrap(err, "failed to extract hardware inspection status")
 		return
@@ -679,7 +690,7 @@ func (p *ironicProvisioner) getUpdateOptsForNode(ironicNode *nodes.Node, checksu
 	return updates, nil
 }
 
-func (p *ironicProvisioner) startProvisioning(ironicNode *nodes.Node, checksum string, getUserData provisioner.UserDataSource) (result provisioner.Result, err error) {
+func (p *ironicProvisioner) startProvisioning(ironicNode *nodes.Node, checksum string, hostConf provisioner.HostConfigData) (result provisioner.Result, err error) {
 
 	p.log.Info("starting provisioning")
 
@@ -778,7 +789,7 @@ func (p *ironicProvisioner) Adopt() (result provisioner.Result, err error) {
 // Provision writes the image from the host spec to the host. It may
 // be called multiple times, and should return true for its dirty flag
 // until the deprovisioning operation is completed.
-func (p *ironicProvisioner) Provision(getUserData provisioner.UserDataSource) (result provisioner.Result, err error) {
+func (p *ironicProvisioner) Provision(hostConf provisioner.HostConfigData) (result provisioner.Result, err error) {
 	var ironicNode *nodes.Node
 
 	if ironicNode, err = p.findExistingHost(); err != nil {
@@ -828,21 +839,28 @@ func (p *ironicProvisioner) Provision(getUserData provisioner.UserDataSource) (r
 			return result, nil
 		}
 		p.log.Info("recovering from previous failure")
-		return p.startProvisioning(ironicNode, checksum, getUserData)
+		return p.startProvisioning(ironicNode, checksum, hostConf)
 
 	case nodes.Manageable:
-		return p.startProvisioning(ironicNode, checksum, getUserData)
+		return p.startProvisioning(ironicNode, checksum, hostConf)
 
 	case nodes.Available:
 		// After it is available, we need to start provisioning by
 		// setting the state to "active".
 		p.log.Info("making host active")
 
-		userData, err := getUserData()
+		userData, err := hostConf.UserData()
 		if err != nil {
 			return result, errors.Wrap(err, "could not retrieve user data")
 		}
 
+		networkDataRaw, err := hostConf.NetworkData()
+
+		var networkData map[string]interface{}
+		if err = yaml.Unmarshal([]byte(networkDataRaw), &networkData); err != nil {
+			return result, errors.Wrap(err, "failed to unmarshal network_data.json from secret")
+		}
+
 		var configDrive nodes.ConfigDrive
 		if userData != "" {
 			configDrive = nodes.ConfigDrive{
@@ -854,7 +872,10 @@ func (p *ironicProvisioner) Provision(getUserData provisioner.UserDataSource) (r
 					"uuid":             string(p.host.ObjectMeta.UID),
 					"metal3-namespace": p.host.ObjectMeta.Namespace,
 					"metal3-name":      p.host.ObjectMeta.Name,
+					"local-hostname":   p.host.ObjectMeta.Name,
+					"local_hostname":   p.host.ObjectMeta.Name,
 				},
+				NetworkData: networkData,
 			}
 			if err != nil {
 				return result, errors.Wrap(err, "failed to build config drive")
